## Summary

- What changed?
- Why is this change needed?

## Type of Change

- [ ] Bug fix
- [ ] New feature
- [ ] Refactor
- [ ] Documentation
- [ ] Tests
- [ ] CI/Tooling

## Validation

- [ ] I ran `ruff` locally for changed Python files.
- [ ] I ran relevant `pytest` tests locally.
- [ ] I added/updated tests for behavior changes.

## Documentation

- [ ] No docs update needed.
- [ ] I updated docs/README for this change.

## Checklist

- [ ] I read `CONTRIBUTING.md`.
- [ ] I confirm this PR is my original work under the repo Apache-2.0 license.
- [ ] I am not including secrets or private credentials.

## Related Issues

Closes #
